@@ -8,7 +8,9 @@ use regex::*;
 use unwrap::unwrap;
 
 lazy_static! {
+    // from this string: authors = ["bestia.dev"]
     static ref REGEX_REMOVE_EMAIL: Regex = unwrap!(Regex::new(r#"( <.+?>)"#));
+    static ref REGEX_EXTRACT_DOMAIN: Regex = unwrap!(Regex::new(r#"@(.+?)>"#));
 }
 
 pub struct CargoToml {
@@ -62,10 +64,10 @@ impl CargoToml {
     }
 
     /// Cargo.toml package authors as string without emails
-    pub fn package_authors_string_without_emails(&self) -> String {
-        let authors = self.package_authors_string();
-        let authors = REGEX_REMOVE_EMAIL.replace_all(&authors, "").to_string();
-        authors
+    pub fn package_author_name(&self) -> String {
+        let author = self.package_authors_string();
+        let author = REGEX_REMOVE_EMAIL.replace_all(&author, "").to_string();
+        author
     }
 
     /// Cargo.toml package repository
@@ -78,6 +80,11 @@ impl CargoToml {
         self.package.description.to_owned()
     }
 
+    /// Cargo.toml package homepage
+    pub fn package_homepage(&self) -> String {
+        self.package.homepage.to_owned().unwrap_or(String::new())
+    }
+
     /// Cargo.toml workspace members
     pub fn workspace_members(&self) -> Option<Vec<String>> {
         match &self.cargo_toml_workspace_maybe.workspace {
@@ -86,3 +93,15 @@ impl CargoToml {
         }
     }
 }
+
+#[cfg(test)]
+mod test {
+    use super::*;
+
+    #[test]
+    pub fn test_cargo_toml() {
+        let cargo_toml = CargoToml::read();
+        assert_eq!(cargo_toml.package_author_name(), "Bestia.dev");
+        assert_eq!(cargo_toml.package_homepage(), "https://bestia.dev");
+    }
+}
